@@ -3,7 +3,7 @@ package Bundle::Compress::Zlib;
 use strict;
 use warnings;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 
 
@@ -95,6 +95,10 @@ IO::Uncompress::Gunzip
 
 Compress::Raw::Zlib
 
+IO::Zlib
+
+IO::Compress::Zlib
+
 Compress::Zlib
 
 =head1 AUTHOR
